

% script to create random tone stimulus (melody/soundscape) using a set of pre-specified paramters -> ARG structure
% similar to limited life-time random dots
% the frequency of each tone is sequentially increased / decreased by 20 cents until the life-time end
%
% the full duration is given by ARG.dots.nframes, where each frame corresponds to a tone (of 30ms
% duration)
%
% The melody is divided into 'epochs', and within each epoch the coherence of motion is randomized
% (around the pre-specified mean coherence level)
%

%--------------------------------------------------------------------
% create stimulus
%--------------------------------------------------------------------
xy = rand(ARG.dots.ndots,1)*(ARG.dots.max_f-ARG.dots.min_f)+ARG.dots.min_f; % random start point
% set 'random' directions to equal proportions for increase or decrease 
dxdyR = cat(1,-1*ones(ARG.dots.ndots/2,1),ones(ARG.dots.ndots/2,1));
dxdyR  = dxdyR(randperm(ARG.dots.ndots)); % randomly assign these to tone Id's
% lifetime of each tone at start is random
lifetime = rem([1:ARG.dots.ndots]',ARG.dots.MaxLife);

Coh_list=[]; 
f0=[];
Motion_list=[];

for f=1:ARG.dots.nframes % number of frames in stimulus. 

  %-----------------------------------------------------------------
  % we need to update the motion vector once we reach the pulse end
  if rem(f,ARG.dots.PULSE_DUR)==1
    % for each pulse, select a random value for the actual coherence in this frame
    frame_coh = randn*ARG.dots.SD + curr_coh;
    frame_coh(find(frame_coh<=0)) = 0;
    frame_coh(find(frame_coh>1)) = 1;
    icoh = randperm(ARG.dots.ndots); % define random proportion that will move coherently
    icoh = icoh([1:round(frame_coh*ARG.dots.ndots)]);
    
    dxdy = dxdyR; % will be the motion vector
    if curr_direction == 2 % down
      dxdy(find(icoh),1) = -1;
    elseif curr_direction == 1 % up
      dxdy(find(icoh),1) = 1;
    end
  end
  
  Coh_list(f) = frame_coh; % coherence value
  Motion_list(f) = mean(dxdy); % actual mean motion evidence. Key variable fo interest. 
  % These may differ depending on tone number due to rounding
  
  
  %-----------------------------------------------------------------
  % generate actual frequencies for each tone ID
  f0(f,:) = xy;
  % move tones
  xy  = xy + dxdy*ARG.dots.dot_speed;
  lifetime = lifetime+1;
  
  % check boundary conditions
  r_out = find(xy > ARG.dots.max_f | xy < ARG.dots.min_f | lifetime>=ARG.dots.MaxLife);
  nout = length(r_out);
  % choose new coordinates that are within the bounds
  xy2 = rand(ARG.dots.ndots,1)*(ARG.dots.max_f-ARG.dots.min_f)+ARG.dots.min_f; % random start point
  r_out2 = find( xy2>ARG.dots.max_f |xy2<ARG.dots.min_f);
  xy2(r_out2,:) = 0;
  xy2 = xy2(find(xy2(:,1)),:);
  % set new position
  xy(r_out,:) = xy2([1:nout],:);
  lifetime(r_out) = 0;
  
end
%--------------------------------------------------------


return;

